@@ -2,6 +2,7 @@
 from pymongo import MongoClient
 from bson.objectid import ObjectId
 
+
 class Backend(object):
     def __init__(self, **kwargs):
         self.database = kwargs.get('database') or 'leselys'
@@ -19,7 +20,8 @@ class Backend(object):
         return res
 
     def add_user(self, username, password):
-        return str(self.db.users.save({'username': username, 'password': password}))
+        return str(self.db.users.save({'username': username,
+                                       'password': password}))
 
     def remove_user(self, username):
         user = self.db.users.find_one({'username': username})
@@ -34,7 +36,8 @@ class Backend(object):
 
     def set_password(self, username, password):
         self.remove_user(username)
-        return str(self.db.users.save({'username': username, 'password': password}))
+        return str(self.db.users.save({'username': username,
+                                       'password': password}))
 
     def set_setting(self, key, value):
         return str(self.db.settings.save({key: value}))
@@ -76,6 +79,16 @@ class Backend(object):
             feed['_id'] = str(feed['_id'])
         return feed
 
+    def update_feed(self, _id, content):
+        self.db.feeds.remove(ObjectId(_id))
+        if content['_id']:
+            if not isinstance(content['_id'], ObjectId):
+                try:
+                    content['_id'] = ObjectId(content['_id'])
+                except:
+                    raise Exception('Update feed failed, cant find _id')
+        return str(self.db.feeds.save(content))
+
     def get_feeds(self):
         res = []
         for feed in self.db.feeds.find():
@@ -96,7 +109,7 @@ class Backend(object):
                 try:
                     content['_id'] = ObjectId(content['_id'])
                 except:
-                    raise Exception('Update story failed, cant find id')
+                    raise Exception('Update story failed, cant find _id')
         return str(self.db.stories.save(content))
 
     def get_story_by_id(self, _id):
